@@ -5,3 +5,7 @@ setOldClass("RQtObject")
 print.RQtObject <- function(x, ...) {
   cat(head(class(x), 1), "instance\n")
 }
+
+print.RQtInvalid <- function(x, ...) {
+  cat("**INVALID** reference to a", class(x)[2], "instance\n")
+}
